@@ -19,7 +19,7 @@
 #' @template seealso
 #' @export
 buildGLMMadaptive <- function (formula,data=NULL,family,cl=NULL,direction=c('order','backward'),crit='LRT',include=NULL,calc.summary=TRUE,...) {
-	if (!requireNamespace('GLMMadaptive',quietly=T)) stop('Please install package GLMMadaptive')
+	if (!requireNamespace('GLMMadaptive',quietly=TRUE)) stop('Please install package GLMMadaptive')
 	p <- list(
 		formula=formula,
 		data=data,
@@ -31,13 +31,13 @@ buildGLMMadaptive <- function (formula,data=NULL,family,cl=NULL,direction=c('ord
 		elim=mkElim(crit),
 		fit=fit.GLMMadaptive,
 		include=include,
-		calc.anova=F,
+		calc.anova=FALSE,
 		calc.summary=calc.summary,
 		family.name=substitute(family),
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=F,
+		can.use.reml=FALSE,
 		env=parent.frame(),
 		dots=list(...)
 	)
@@ -58,7 +58,7 @@ buildGLMMadaptive <- function (formula,data=NULL,family,cl=NULL,direction=c('ord
 #' 
 #' \code{lme4} random effects are supported: they will be automatically converted using \code{\link{re2mgcv}}.
 #' 
-#' As \code{bam} uses PQL, only \code{crit='deviance'} is supported.
+#' As \code{bam} uses PQL, only \code{crit='deviance'} is supported for non-Gaussian errors.
 #' @examples
 #' \dontshow{
 #' library(buildmer)
@@ -72,7 +72,7 @@ buildGLMMadaptive <- function (formula,data=NULL,family,cl=NULL,direction=c('ord
 #' @template seealso
 #' @importFrom stats gaussian
 #' @export
-buildbam <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('order','backward'),crit='deviance',include=NULL,calc.anova=FALSE,calc.summary=TRUE,...) {
+buildbam <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('order','backward'),crit='LRT',include=NULL,calc.anova=FALSE,calc.summary=TRUE,...) {
 	p <- list(
 		formula=formula,
 		data=data,
@@ -91,13 +91,13 @@ buildbam <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('o
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=T,
+		can.use.reml=TRUE,
 		env=parent.frame(),
 		dots=list(...)
 	)
 	if ('intercept' %in% names(p$data)) stop("To enable buildbam() to work around a problem in bam(), please remove or rename the column named 'intercept' from your data")
 	if (isTRUE(p$dots$I_KNOW_WHAT_I_AM_DOING)) p$dots$I_KNOW_WHAT_I_AM_DOING <- NULL
-	else if (!all(crit == 'deviance') || !(is.gaussian(family)) && is.null(lme4::findbars(formula)) && !has.smooth.terms(formula)) stop("bam() uses PQL, which means that likelihood-based model comparisons are not valid. Try using buildgam() instead, or use crit='deviance'.")
+	else if (!all(p$crit.name %in% c('custom','deviance','devexp')) && !is.gaussian(p$family)) stop(progress("bam() uses PQL, which means that likelihood-based model comparisons are not valid in the generalized case. Try using buildgam() instead, or use crit='deviance' (note that this is not a formal test). Alternatively, find a way to fit your model using Gaussian errors. (If you really know what you are doing, you can sidestep this error by passing I_KNOW_WHAT_I_AM_DOING=TRUE)"))
 	p <- buildmer.fit(p)
 	buildmer.finalize(p)
 }
@@ -123,14 +123,14 @@ buildbam <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('o
 #'     test <- try(anova(m))
 #'     if (inherits(test,'try-error')) test else m
 #' }
-#' crit.F <- function (ma,mb) { # use whole-model F
-#'     pvals <- anova(mb)$'Pr(>F)' # not valid for backward!
+#' crit.F <- function (p,a,b) { # use whole-model F
+#'     pvals <- anova(b)$'Pr(>F)' # not valid for backward!
 #'     pvals[length(pvals)-1]
 #' }
-#' crit.Wilks <- function (ma,mb) {
-#'     if (is.null(ma)) return(crit.F(ma,mb)) #not completely correct, but close as F approximates X2
-#'     Lambda <- anova(mb,test='Wilks')$Wilks[1]
-#'     p <- length(coef(mb))
+#' crit.Wilks <- function (p,a,b) {
+#'     if (is.null(a)) return(crit.F(p,a,b)) #not completely correct, but close as F approximates X2
+#'     Lambda <- anova(b,test='Wilks')$Wilks[1]
+#'     p <- length(coef(b))
 #'     n <- 1
 #'     m <- nrow(migrant)
 #'     Bartlett <- ((p-n+1)/2-m)*log(Lambda)
@@ -146,15 +146,15 @@ buildbam <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('o
 #'        multilingual,data=migrant)
 #' @template seealso
 #' @export
-buildcustom <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),crit=function (ref,alt) stop("'crit' not specified"),include=NULL,fit=function (p,formula) stop("'fit' not specified"),elim=function (x) stop("'elim' not specified"),REML=FALSE,...) {
+buildcustom <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),crit=function (p,ref,alt) stop("'crit' not specified"),include=NULL,fit=function (p,formula) stop("'fit' not specified"),elim=function (x) stop("'elim' not specified"),REML=FALSE,...) {
 	p <- list(
 		formula=formula,
 		data=data,
 		cluster=cl,
 		direction=direction,
 		include=include,
-		calc.anova=F,
-		calc.summary=F,
+		calc.anova=FALSE,
+		calc.summary=FALSE,
 		ddf=NULL,
 		data.name=substitute(data),
 		subset.name=substitute(subset),
@@ -225,21 +225,21 @@ buildgam <- function (formula,data=NULL,family=gaussian(),quickstart=0,cl=NULL,d
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=T,
+		can.use.reml=TRUE,
 		env=parent.frame(),
 		dots=list(...)
 	)
-	if (is.null(p$data)) stop("Sorry, buildgam() requires data to be passed via the data= argument")
+	if (is.null(p$data)) stop('Sorry, buildgam() requires data to be passed via the data= argument')
 	if ('intercept' %in% names(p$data)) stop("To enable buildgam() to work around a problem in gam(), please remove or rename the column named 'intercept' from your data")
 	if (isTRUE(p$dots$I_KNOW_WHAT_I_AM_DOING)) p$dots$I_KNOW_WHAT_I_AM_DOING <- NULL else {
 		if (is.character(family)) family <- get(family)
 		if (is.function (family)) family <- family()
-		if (!all(crit %in% c('deviance','devexp')) && !is.null(p$dots$optimizer[1]) && p$dots$optimizer[1] != 'outer') stop("You are trying to use buildgam() using performance iteration or the EFS optimizer. In this situation, gam() uses PQL, which means that likelihood-based model comparisons are invalid in the generalized case. Try using buildgam() with outer iteration instead (e.g. buildgam(...,optimizer=c('outer','",if (family$family == 'gaussian') "newton'))), or use buildgamm()" else "bfgs')))",". (If you really know what you are doing, you can sidestep this error by passing an argument 'I_KNOW_WHAT_I_AM_DOING'.)")
+		if (!all(p$crit.name %in% c('custom','deviance','devexp')) && !is.null(p$dots$optimizer[1]) && p$dots$optimizer[1] != 'outer' && !is.gaussian(p$family)) stop(progress("You are trying to use buildgam() using performance iteration or the EFS optimizer. In this situation, gam() uses PQL, which means that likelihood-based model comparisons are invalid in the generalized case. Try using buildgam() with outer iteration instead (e.g. buildgam(...,optimizer=c('outer','bfgs'))), use crit='deviance' (note that this is not a formal test), or find a way to fit your model using Gaussian errors. (If you really know what you are doing, you can sidestep this error by passing I_KNOW_WHAT_I_AM_DOING=TRUE.)"))
 		if (inherits(family,'general.family')) {
 			if (p$quickstart) stop('Quickstart is not possible with the ',family$family,' family')
-			p$can.use.reml <- F
-			warning('The ',family$family," family can only be fitted using REML. Adding select=TRUE to gam()'s command arguments (see ?gam to review the implications), and refusing to eliminate fixed effects")
-			p$dots$select <- T
+			p$can.use.reml <- FALSE
+			warning(progress('The ',family$family," family can only be fitted using REML. Adding select=TRUE to gam()'s command arguments (see ?gam to review the implications), and refusing to eliminate fixed effects"))
+			p$dots$select <- TRUE
 			if (!is.data.frame(p$formula)) {
 				p$dots$dep <- as.character(p$formula[2])
 				p$formula <- tabulate.formula(p$formula)
@@ -292,9 +292,9 @@ buildgamm <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=T,
+		can.use.reml=TRUE,
 		env=parent.frame(),
-		finalize=F,
+		finalize=FALSE,
 		dots=list(...)
 	)
 	if (!is.gaussian(family)) {
@@ -304,7 +304,7 @@ buildgamm <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('
 	p <- buildmer.fit(p)
 	if (has.smooth.terms(p$formula)) {
 		message('Fitting final gamm model')
-		p$reml <- p$finalize <- T
+		p$reml <- p$finalize <- TRUE
 		p$model <- fit.gamm(p,p$formula)
 	}
 	buildmer.finalize(p)
@@ -335,7 +335,7 @@ buildgamm <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('
 #' @importFrom stats gaussian
 #' @export
 buildgamm4 <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('order','backward'),crit='LRT',include=NULL,calc.anova=FALSE,calc.summary=TRUE,ddf='Wald',...) {
-	if (!requireNamespace('gamm4',quietly=T)) stop('Please install package gamm4')
+	if (!requireNamespace('gamm4',quietly=TRUE)) stop('Please install package gamm4')
 	p <- list(
 		formula=formula,
 		data=data,
@@ -356,13 +356,13 @@ buildgamm4 <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c(
 		control.name=substitute(control),
 		can.use.reml=is.gaussian(family),
 		env=parent.frame(),
-		finalize=F,
+		finalize=FALSE,
 		dots=list(...)
 	)
 	p <- buildmer.fit(p)
 	if (has.smooth.terms(p$formula)) {
 		message('Fitting final gamm4 model')
-		p$reml <- p$finalize <- T
+		p$reml <- p$finalize <- TRUE
 		p$model <- fit.gamm4(p,p$formula)
 	}
 	buildmer.finalize(p)
@@ -379,19 +379,11 @@ buildgamm4 <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c(
 #' library(buildmer)
 #' model <- if (requireNamespace('glmmTMB')) buildglmmTMB(Reaction ~ Days + (Days|Subject)
 #'        ,data=lme4::sleepstudy)
-#' \dontshow{\donttest{
-#' # What's the point of both \dontshow and \donttest, you ask? I want this to be tested when checking my package with --run-donttest, but the model is statistically nonsensical, so no good in showing it to the user!
-#' vowels$event <- with(vowels,interaction(participant,word))
-#' if (requireNamespace('glmmTMB')) {
-#' 	# converges with MKL, not with R default BLAS
-#' 	model <- try(buildglmmTMB(f1 ~ timepoint,include=~ar1(0+participant|event),data=vowels))
-#' }
-#' }}
 #' @template seealso
 #' @importFrom stats gaussian
 #' @export
 buildglmmTMB <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('order','backward'),crit='LRT',include=NULL,calc.summary=TRUE,...) {
-	if (!requireNamespace('glmmTMB',quietly=T)) stop('Please install package glmmTMB')
+	if (!requireNamespace('glmmTMB',quietly=TRUE)) stop('Please install package glmmTMB')
 	p <- list(
 		formula=formula,
 		data=data,
@@ -403,13 +395,13 @@ buildglmmTMB <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=
 		elim=mkElim(crit),
 		fit=fit.glmmTMB,
 		include=include,
-		calc.anova=F,
+		calc.anova=FALSE,
 		calc.summary=calc.summary,
 		family.name=substitute(family),
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=T,
+		can.use.reml=TRUE,
 		env=parent.frame(),
 		dots=list(...)
 	)
@@ -451,7 +443,7 @@ buildgls <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=T,
+		can.use.reml=TRUE,
 		env=parent.frame(),
 		dots=list(...)
 	)
@@ -479,7 +471,8 @@ buildgls <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),
 #' @importFrom stats gaussian
 #' @export
 buildjulia <- function (formula,data=NULL,family=gaussian(),include=NULL,julia_family=gaussian(),julia_link=NULL,julia_fun=NULL,direction=c('order','backward'),crit='LRT',...) {
-	if (!requireNamespace('JuliaCall',quietly=T)) stop('Please install package JuliaCall')
+	warning(progress("buildjulia() is deprecated and will be removed in a future version of buildmer! There is no replacement, but you should be able to cook one up yourself using buildcustom() (note that the various julia-specific functions such as AIC.julia will also be removed). Sorry, the maintenance cost/benefit trade-off is just too negative!"))
+	if (!requireNamespace('JuliaCall',quietly=TRUE)) stop('Please install package JuliaCall')
 	p <- list(
 		formula=formula,
 		data=data,
@@ -493,17 +486,17 @@ buildjulia <- function (formula,data=NULL,family=gaussian(),include=NULL,julia_f
 		crit.name=mkCritName(crit),
 		elim=mkElim(crit),
 		fit=fit.julia,
-		calc.anova=F,
-		calc.summary=F,
+		calc.anova=FALSE,
+		calc.summary=FALSE,
 		can.use.reml=is.gaussian(family),
 		env=parent.frame(),
 		dots=list(...)
 	)
 
 	message('Setting up Julia...')
-	p$julia <- JuliaCall::julia_setup(verbose=T)
+	p$julia <- JuliaCall::julia_setup(verbose=TRUE)
 	p$julia$library('MixedModels')
-	p$crit <- function (ref,alt) mkCrit(paste0(crit,'.julia'))(p$julia,ref,alt)
+	p$crit <- function (p,ref,alt) mkCrit(paste0(crit,'.julia'))(p,ref,alt)
 
 	p <- buildmer.fit(p)
 	buildmer.finalize(p)
@@ -525,7 +518,7 @@ buildjulia <- function (formula,data=NULL,family=gaussian(),include=NULL,julia_f
 #' @template seealso
 #' @export
 buildlme <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),crit='LRT',include=NULL,calc.anova=FALSE,calc.summary=TRUE,...) {
-	if (!requireNamespace('nlme',quietly=T)) stop('Please install package nlme')
+	if (!requireNamespace('nlme',quietly=TRUE)) stop('Please install package nlme')
 	p <- list(
 		formula=formula,
 		data=data,
@@ -543,7 +536,7 @@ buildlme <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=T,
+		can.use.reml=TRUE,
 		env=parent.frame(),
 		dots=list(...)
 	)
@@ -599,7 +592,7 @@ buildmer <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('o
 		dots=list(...)
 	)
 	p <- buildmer.fit(p)
-	if (inherits(p$model,'lmerMod') && requireNamespace('lmerTest',quietly=T)) {
+	if (inherits(p$model,'lmerMod') && requireNamespace('lmerTest',quietly=TRUE)) {
 		# Even if the user did not request lmerTest ddf, convert the model to an lmerTest object anyway in case the user is like me and only thinks about the ddf after having fitted the model
 		message('Finalizing by converting the model to lmerTest')
 		p$model@call$data <- p$data
@@ -633,8 +626,8 @@ buildmer <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('o
 #' @importFrom stats gaussian
 #' @export
 buildmertree <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=c('order','backward'),crit='AIC',include=NULL,calc.summary=TRUE,...) {
-	if (!requireNamespace('glmertree',quietly=T)) stop('Please install package glmertree')
-	if (!requireNamespace('partykit',quietly=T)) stop('Please install package partykit')
+	if (!requireNamespace('glmertree',quietly=TRUE)) stop('Please install package glmertree')
+	if (!requireNamespace('partykit',quietly=TRUE)) stop('Please install package partykit')
 	if (any( (is.character(crit) & crit == 'LRT') | (!is.character(crit) & isTRUE(all.equal(crit,crit.LRT))) )) stop("The likelihood-ratio test is not suitable for glmertree models, as there is no way to guarantee that two models being compared are nested. It is suggested to use the raw log-likelihood instead (crit='LL') and only perform the term-ordering step (direction='order'). If you require stepwise elimination, information criteria such as AIC should be valid.")
 
 	dots <- list(...)
@@ -667,13 +660,13 @@ buildmertree <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=
 		elim=mkElim(crit),
 		fit=fit.mertree,
 		include=include,
-		calc.anova=F,
+		calc.anova=FALSE,
 		calc.summary=calc.summary,
 		ddf=NULL,
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=if (is.gaussian(family)) substitute(lmer.control) else substitute(glmer.control),
-		can.use.reml=F,
+		can.use.reml=FALSE,
 		env=parent.frame(),
 		dots=dots
 	)
@@ -697,7 +690,7 @@ buildmertree <- function (formula,data=NULL,family=gaussian(),cl=NULL,direction=
 #' @template seealso
 #' @export
 buildmultinom <- function (formula,data=NULL,cl=NULL,direction=c('order','backward'),crit='LRT',include=NULL,calc.summary=TRUE,...) {
-	if (!requireNamespace('nnet',quietly=T)) stop('Please install package nnet')
+	if (!requireNamespace('nnet',quietly=TRUE)) stop('Please install package nnet')
 	p <- list(
 		formula=formula,
 		data=data,
@@ -708,13 +701,13 @@ buildmultinom <- function (formula,data=NULL,cl=NULL,direction=c('order','backwa
 		elim=mkElim(crit),
 		fit=fit.multinom,
 		include=include,
-		calc.anova=F,
+		calc.anova=FALSE,
 		calc.summary=calc.summary,
 		ddf=NULL,
 		data.name=substitute(data),
 		subset.name=substitute(subset),
 		control.name=substitute(control),
-		can.use.reml=F,
+		can.use.reml=FALSE,
 		env=parent.frame(),
 		dots=list(...)
 	)
